################################################################################################################ -
# Replication for: Individual-Specific Point and Interval Conditional Estimates of Latent Class Logit Parameters
# By: Mauricio Sarrias
################################################################################################################ -


## ---- Generate Table 1 (Latex Format) ---------------
rm(list = ls(all = TRUE))
load("LC_experimentAll.RData") # Load results from Monte Carlo 
source('helpers.R')            # Helper for creation of tables
library('xtable')

# Table for results
Table_1 <- matrix(NA, nrow = 10, ncol = 11)

for (t in 1:5) {
   out <- stats_bi(bhat = bi1.sim.e1[, , t],
                   se   = si1.sim.e1[, , t],
                   true = b1_e1,
                   drop = 5,
                   alternative = FALSE)
   out2 <- stats_bi(bhat = bi1b.sim.e1[, , t],
                    se   = si1b.sim.e1[, , t],
                    true = b1_e1,
                    drop = 5)
   out3 <- stats_bi(bhat = bi1b.sim.e1[, , t],
                    se   = si1b.sim.e1[, , t],
                    true = b1_e1,
                    drop = 5,
                    lbb = li1b.sim.e1[, , t],
                    ubb = ui1b.sim.e1[, , t])
   outB <- stats_bi(bhat = bi1.sim.e2[, , t],
                    se   = si1.sim.e2[, , t],
                    true = b1_e2,
                    drop = 5,
                    alternative = FALSE)
   out2B <- stats_bi(bhat = bi1b.sim.e2[, , t],
                    se   = si1b.sim.e2[, , t],
                    true = b1_e2,
                    drop = 5)
   out3B <- stats_bi(bhat = bi1b.sim.e2[, , t],
                    se   = si1b.sim.e2[, , t],
                    true = b1_e2,
                    drop = 5,
                    lbb = li1b.sim.e2[, , t],
                    ubb = ui1b.sim.e2[, , t])
   Table_1[t, 1] <- mean(out$mean.S)
   Table_1[t, 2] <- out$bias_1
   Table_1[t, 3] <- mean(out$sd.S)
   Table_1[t, 4] <- out$av.coverage
   Table_1[t, 5] <- out$S
   Table_1[t, 6] <- mean(out2$mean.S)
   Table_1[t, 7] <- out2$bias_1
   Table_1[t, 8] <- mean(out2$sd.S)
   Table_1[t, 9] <- out2$av.coverage
   Table_1[t, 10] <- out2$S
   Table_1[t, 11] <- out3$av.coverage
   Table_1[t + 5, 1] <- mean(outB$mean.S)
   Table_1[t + 5, 2] <- outB$bias_1
   Table_1[t + 5, 3] <- mean(outB$sd.S)
   Table_1[t + 5, 4] <- outB$av.coverage
   Table_1[t + 5, 5] <- outB$S
   Table_1[t + 5, 6] <- mean(out2B$mean.S)
   Table_1[t + 5, 7] <- out2B$bias_1
   Table_1[t + 5, 8] <- mean(out2B$sd.S)
   Table_1[t + 5, 9] <- out2B$av.coverage
   Table_1[t + 5, 10] <- out2B$S
   Table_1[t + 5, 11] <- out3B$av.coverage
}

## Table for latex
rownames(Table_1) <- c("T = 1", "T = 5", "T = 10", "T = 20", "T = 50",
                       " T = 1", " T = 5", " T = 10", " T = 20", " T = 50")
Table_1 <- xtable(Table_1,
                 caption = "Simulation results for LC-MNL model with 2 Classes. The results are averaged over S.",
                 label = "table1")
align(Table_1) <- "l|ccccc|cccccc"
digits(Table_1) <- c(0, rep(3, 4), 0, rep(3, 4), 0, 3)
addtorow <- list()
addtorow$pos <- list(0, 0, 0, 5)
addtorow$command <- c("& \\multicolumn{5}{c}{Point Estimate} & \\multicolumn{6}{c}{Sampling Distribution} \\\\\n",
                      "& \\emph{Mean} & \\emph{Bias} & \\emph{SD} & \\emph{Cov} & \\emph{S} & \\emph{Mean} & \\emph{Bias} & \\emph{SD} & \\emph{Cov A} & \\emph{S} & \\emph{Cov B} \\\\\n", 
                      "& \\multicolumn{11}{c}{\\textbf{Panel A: N = 300}} \\\\\n",
                      "& \\multicolumn{11}{c}{\\textbf{Panel B: N = 1000}} \\\\\n")


print(Table_1, 
      booktabs = TRUE,
      tabular.environment = "longtable",
      add.to.row = addtorow,
      include.colnames = FALSE,
      include.rownames = TRUE,
      hline.after = c(-1, 0, 5, 10),
      latex.environments = "center",
      table.placement = "ht")

## ---- Generate Table 2 (Latex Format) ---------------
rm(list = ls(all = TRUE))
load("LC_experimentAllMiss.RData")
source('helpers.R')
library('xtable')

# Table for results
Table_2 <- matrix(NA, nrow = 5, ncol = 11)

for (t in 1:5) {
   out <- stats_bi(bhat = bi1.sim.e3[, , t],
                   se   = si1.sim.e3[, , t],
                   true = b1_e3,
                   drop = 100,
                   alternative = FALSE)
   out2 <- stats_bi(bhat = bi1b.sim.e3[, , t],
                    se   = si1b.sim.e3[, , t],
                    true = b1_e3,
                    drop = 100)
   out3 <- stats_bi(bhat = bi1b.sim.e3[, , t],
                    se   = si1b.sim.e3[, , t],
                    true = b1_e3,
                    drop = 100,
                    lbb = li1b.sim.e3[, , t],
                    ubb = ui1b.sim.e3[, , t])
   Table_2[t, 1] <- mean(out$mean.S)
   Table_2[t, 2] <- out$bias_1
   Table_2[t, 3] <- mean(out$sd.S)
   Table_2[t, 4] <- out$av.coverage
   Table_2[t, 5] <- out$S
   Table_2[t, 6] <- mean(out2$mean.S)
   Table_2[t, 7] <- out2$bias_1
   Table_2[t, 8] <- mean(out2$sd.S)
   Table_2[t, 9] <- out2$av.coverage
   Table_2[t, 10] <- out2$S
   Table_2[t, 11] <- out3$av.coverage
}

## Table for latex
rownames(Table_2) <- c("T = 1", "T = 5", "T = 10", "T = 20", "T = 50")
Table_2 <- xtable(Table_2,
                 caption = "Simulation results for LC-MNL model with 3 Classes. The results are averaged over S.",
                 label = "table2")
align(Table_2) <- "l|ccccc|cccccc"
digits(Table_2) <- c(0, rep(3, 4), 0, rep(3, 4), 0, 3)
addtorow <- list()
addtorow$pos <- list(0, 0, 0)
addtorow$command <- c("& \\multicolumn{5}{c}{Point Estimate} & \\multicolumn{6}{c}{Sampling Distribution} \\\\\n",
                      "& \\emph{Mean} & \\emph{Bias} & \\emph{SD} & \\emph{Cov} & \\emph{S} & \\emph{Mean} & \\emph{Bias} & \\emph{SD} & \\emph{Cov A} & \\emph{S} & \\emph{Cov B} \\\\\n", 
                      "& \\multicolumn{11}{c}{\\textbf{N = 1000}} \\\\\n")


print(Table_2, 
      booktabs = TRUE,
      tabular.environment = "longtable",
      add.to.row = addtorow,
      include.colnames = FALSE,
      include.rownames = TRUE,
      #hline.after = c(-1, 0, 5, 10),
      latex.environments = "center",
      table.placement = "ht")

## ---- Plot Figure 1 -----------
rm(list = ls(all = TRUE))
source('helpers.R')
load("LC_experimentAll.RData")
out1_b1 <- stats_bi(bhat = bi1.sim.e2[, , 1],
                 se   = si1.sim.e2[, , 1],
                 true = b1_e2,
                 drop = 4)
out1_b2 <- stats_bi(bhat = bi1.sim.e2[, , 2],
                    se   = si1.sim.e2[, , 2],
                    true = b1_e2,
                    drop = 4)
out1_b3 <- stats_bi(bhat = bi1.sim.e2[, , 3],
                    se   = si1.sim.e2[, , 3],
                    true = b1_e2)
out1_b4 <- stats_bi(bhat = bi1.sim.e2[, , 4],
                    se   = si1.sim.e2[, , 4],
                    true = b1_e2,
                    drop = 4)
out1_b5 <- stats_bi(bhat = bi1.sim.e2[, , 5],
                    se   = si1.sim.e2[, , 5],
                    true = b1_e2,
                    drop = 4)

out1b_b1 <- stats_bi(bhat = bi1b.sim.e2[, , 1],
                    se   = si1b.sim.e2[, , 1],
                    true = b1_e2,
                    drop = 4)
out1b_b2 <- stats_bi(bhat = bi1b.sim.e2[, , 2],
                    se   = si1b.sim.e2[, , 2],
                    true = b1_e2,
                    drop = 4)
out1b_b3 <- stats_bi(bhat = bi1b.sim.e2[, , 3],
                    se   = si1b.sim.e2[, , 3],
                    true = b1_e2,
                    drop = 4)
out1b_b4 <- stats_bi(bhat = bi1b.sim.e2[, , 4],
                    se   = si1b.sim.e2[, , 4],
                    true = b1_e2,
                    drop = 4)
out1b_b5 <- stats_bi(bhat = bi1b.sim.e2[, , 5],
                    se   = si1b.sim.e2[, , 5],
                    true = b1_e2,
                    drop = 4)

load("LC_experimentAllMiss.RData")
out1_b1_q3 <- stats_bi(bhat = bi1.sim.e3[, , 1],
                 se   = si1.sim.e3[, , 1],
                 true = b1_e3,
                 drop = 4)
out1_b2_q3  <- stats_bi(bhat = bi1.sim.e3[, , 2],
                    se   = si1.sim.e3[, , 2],
                    true = b1_e3,
                    drop = 4)
out1_b3_q3 <- stats_bi(bhat = bi1.sim.e3[, , 3],
                    se   = si1.sim.e3[, , 3],
                    true = b1_e3)
out1_b4_q3 <- stats_bi(bhat = bi1.sim.e3[, , 4],
                    se   = si1.sim.e3[, , 4],
                    true = b1_e3,
                    drop = 4)
out1_b5_q3 <- stats_bi(bhat = bi1.sim.e3[, , 5],
                    se   = si1.sim.e3[, , 5],
                    true = b1_e3,
                    drop = 4)

out1b_b1_q3 <- stats_bi(bhat = bi1b.sim.e3[, , 1],
                    se   = si1b.sim.e3[, , 1],
                    true = b1_e3,
                    drop = 4)
out1b_b2_q3 <- stats_bi(bhat = bi1b.sim.e3[, , 2],
                    se   = si1b.sim.e3[, , 2],
                    true = b1_e3,
                    drop = 4)
out1b_b3_q3 <- stats_bi(bhat = bi1b.sim.e3[, , 3],
                    se   = si1b.sim.e3[, , 3],
                    true = b1_e3,
                    drop = 4)
out1b_b4_q3 <- stats_bi(bhat = bi1b.sim.e3[, , 4],
                    se   = si1b.sim.e3[, , 4],
                    true = b1_e3,
                    drop = 4)
out1b_b5_q3 <- stats_bi(bhat = bi1b.sim.e3[, , 5],
                    se   = si1b.sim.e3[, , 5],
                    true = b1_e3,
                    drop = 4)



par(mfrow = c(2, 2), cex = 0.6)       
plot(density(b1_e1), lwd = 2, lty = 1, 
    ylim = c(0, 0.6),
    xlab = expression(hat(E)(beta[i])),
    main = "A: Point Estimate, Q = 2",
    col = "gray0")
lines(density(out1_b1$av.bi), col = "gray12", lwd = 2, lty = 2)
lines(density(out1_b2$av.bi), col = "gray25", lwd = 2, lty = 3)
lines(density(out1_b3$av.bi), col = "gray35", lwd = 2, lty = 4)
lines(density(out1_b4$av.bi), col = "gray45", lwd = 2, lty = 5)
lines(density(out1_b5$av.bi), col = "gray55", lwd = 2, lty = 6)
legend("topright", 
       c("True", "T = 1", "T = 5", "T = 10", "T = 20", "T = 50"),
       lty = c(1, 2, 3, 4, 5, 6),
       col = c("gray0", "gray12", "gray25", "gray35", "gray45", "gray55"))
plot(density(b1_e1), lwd = 2, lty = 1, 
     ylim = c(0, 0.6),
     xlab = expression(hat(E)(beta[i])),
     main = "B: Sampling Distribution, Q = 2",
     col = "gray0")
lines(density(out1b_b1$av.bi), col = "gray12", lwd = 2, lty = 2)
lines(density(out1b_b2$av.bi), col = "gray25", lwd = 2, lty = 3)
lines(density(out1b_b3$av.bi), col = "gray35", lwd = 2, lty = 4)
lines(density(out1b_b4$av.bi), col = "gray45", lwd = 2, lty = 5)
lines(density(out1b_b5$av.bi), col = "gray55", lwd = 2, lty = 6)
legend("topright", 
       c("True", "T = 1", "T = 5", "T = 10", "T = 20", "T = 50"),
       lty = c(1, 2, 3, 4, 5, 6),
       col = c("gray0", "gray12", "gray25", "gray35", "gray45", "gray55"))
plot(density(b1_e3), lwd = 2, lty = 1, 
    ylim = c(0, 1.3),
    xlab = expression(hat(E)(beta[i])),
    main = "C: Point Estimate, Q = 3",
    col = "gray0")
lines(density(out1_b1_q3$av.bi), col = "gray12", lwd = 2, lty = 2)
lines(density(out1_b2_q3$av.bi), col = "gray25", lwd = 2, lty = 3)
lines(density(out1_b3_q3$av.bi), col = "gray35", lwd = 2, lty = 4)
lines(density(out1_b4_q3$av.bi), col = "gray45", lwd = 2, lty = 5)
lines(density(out1_b5_q3$av.bi), col = "gray55", lwd = 2, lty = 6)
legend("topright", 
       c("True", "T = 1", "T = 5", "T = 10", "T = 20", "T = 50"),
       lty = c(1, 2, 3, 4, 5, 6),
       col = c("gray0", "gray12", "gray25", "gray35", "gray45", "gray55"))
plot(density(b1_e3), lwd = 2, lty = 1, 
     ylim = c(0, 1.3),
     xlab = expression(hat(E)(beta[i])),
     main = "D: Sampling Distribution, Q = 3",
     col = "gray0")
lines(density(out1b_b1_q3$av.bi), col = "gray12", lwd = 2, lty = 2)
lines(density(out1b_b2_q3$av.bi), col = "gray25", lwd = 2, lty = 3)
lines(density(out1b_b3_q3$av.bi), col = "gray35", lwd = 2, lty = 4)
lines(density(out1b_b4_q3$av.bi), col = "gray45", lwd = 2, lty = 5)
lines(density(out1b_b5_q3$av.bi), col = "gray55", lwd = 2, lty = 6)
legend("topright", 
       c("True", "T = 1", "T = 5", "T = 10", "T = 20", "T = 50"),
       lty = c(1, 2, 3, 4, 5, 6),
       col = c("gray0", "gray12", "gray25", "gray35", "gray45", "gray55"))

## ----Generate Table 3 (Latex Format)---------------
rm(list = ls(all = TRUE))
load("LC_experimentAllMiss.RData")
source('helpers.R')
library('xtable')

# Table for results
Table_1 <- matrix(NA, nrow = 10, ncol = 4)

for (t in 1:5) {
   out <- stats_class(bhat       = bi1.sim.e3[, , t], 
                      hat_class  = clas.as3[, , t], 
                      true_class = true_class_e3, 
                      Q = 3, 
                      drop = 4)
   Table_1[t, 1] <- out$flag
   Table_1[t, 2] <- out$pc[1]
   Table_1[t, 3] <- out$pc[2]
   Table_1[t, 4] <- out$pc[3]
   Table_1[t + 5, 2] <- mean(share1.e3[ ,t])
   Table_1[t + 5, 3] <- mean(share2.e3[, t])
   Table_1[t + 5, 4] <- mean(share3.e3[, t])
}

## Table for latex
rownames(Table_1) <- c("T = 1", "T = 5", "T = 10", "T = 20", "T = 50",
                       " T = 1", " T = 5", " T = 10", " T = 20", " T = 50")
Table_1 <- xtable(Table_1,
                 caption = "Predicted shares for each class. Panel A based on posterior probabilities. Panel B based on structural parameters.  Simulation results for LC-MNL Model with 3 classes. Results averaged over S.",
                 label = "table4")
align(Table_1) <- "l|cccc"
digits(Table_1) <- c(0, rep(3, 4))
addtorow <- list()
addtorow$pos <- list(0, 0, 5)
addtorow$command <- c("& \\% Correct prediction& \\% Class 1 & \\% Class 2 & \\% Class 3 \\\\\n", 
                      "& \\multicolumn{4}{c}{\\textbf{Panel A: Based on posterior probability}} \\\\\n", 
                      "& \\multicolumn{4}{c}{\\textbf{Panel B: Based on Logit formula}} \\\\\n")



print(Table_1, 
      booktabs = TRUE,
      tabular.environment = "longtable",
      add.to.row = addtorow,
      include.colnames = FALSE,
      include.rownames = TRUE,
      hline.after = c(-1, 0, 5, 10),
      latex.environments = "center",
      table.placement = "ht")

## ---- Generate Table 4 (Latex Format)---------------
rm(list = ls(all = TRUE))
load("LC_experimentAllMiss.RData")
source('helpers.R')
library('xtable')

# Table for results
Table_2 <- matrix(NA, nrow = 5, ncol = 11)

for (t in 1:5) {
   out <- stats_bi(bhat = bi1w.sim.e3[, , t],
                   se   = si1w.sim.e3[, , t],
                   true = b1_e3,
                   drop = 4,
                   alternative = FALSE)
   out2 <- stats_bi(bhat = bi1bw.sim.e3[, , t],
                    se   = si1bw.sim.e3[, , t],
                    true = b1_e3,
                    drop = 4)
   out3 <- stats_bi(bhat = bi1bw.sim.e3[, , t],
                    se   = si1bw.sim.e3[, , t],
                    true = b1_e3,
                    drop = 4,
                    lbb = li1bw.sim.e3[, , t],
                    ubb = ui1bw.sim.e3[, , t])
   Table_2[t, 1] <- mean(out$mean.S)
   Table_2[t, 2] <- out$bias_1
   Table_2[t, 3] <- mean(out$sd.S)
   Table_2[t, 4] <- out$av.coverage
   Table_2[t, 5] <- out$S
   Table_2[t, 6] <- mean(out2$mean.S)
   Table_2[t, 7] <- out2$bias_1
   Table_2[t, 8] <- mean(out2$sd.S)
   Table_2[t, 9] <- out2$av.coverage
   Table_2[t, 10] <- out2$S
   Table_2[t, 11] <- out3$av.coverage
}

## Table for latex
rownames(Table_2) <- c("T = 1", "T = 5", "T = 10", "T = 20", "T = 50")
Table_2 <- xtable(Table_2,
                 caption = "Simulation Results for LC Model",
                 label = "table3")
align(Table_2) <- "l|ccccc|cccccc"
digits(Table_2) <- c(0, rep(3, 4), 0, rep(3, 4), 0, 3)
addtorow <- list()
addtorow$pos <- list(0, 0, 0)
addtorow$command <- c("& \\multicolumn{5}{c}{Point Estimate} & \\multicolumn{6}{c}{Sampling Distribution} \\\\\n",
                      "& \\emph{Mean} & \\emph{Bias} & \\emph{SD} & \\emph{Cov} & \\emph{S} & \\emph{Mean} & \\emph{Bias} & \\emph{SD} & \\emph{Cov} & \\emph{S} & \\emph{Cov} \\\\\n", 
                      "& \\multicolumn{11}{c}{\\textbf{N = 1000}} \\\\\n")


print(Table_2, 
      booktabs = TRUE,
      tabular.environment = "longtable",
      add.to.row = addtorow,
      include.colnames = FALSE,
      include.rownames = TRUE,
      #hline.after = c(-1, 0, 5, 10),
      latex.environments = "center",
      table.placement = "ht")

## ---- Plot Figure 2 ------
rm(list = ls(all = TRUE))
load("LC_experimentAllMiss.RData")
source('helpers.R')
out1_b1_q3 <- stats_bi(bhat = bi1w.sim.e3[, , 1],
                 se   = si1w.sim.e3[, , 1],
                 true = b1_e3,
                 drop = 4)
out1_b2_q3  <- stats_bi(bhat = bi1w.sim.e3[, , 2],
                    se   = si1w.sim.e3[, , 2],
                    true = b1_e3,
                    drop = 4)
out1_b3_q3 <- stats_bi(bhat = bi1w.sim.e3[, , 3],
                    se   = si1w.sim.e3[, , 3],
                    true = b1_e3)
out1_b4_q3 <- stats_bi(bhat = bi1w.sim.e3[, , 4],
                    se   = si1w.sim.e3[, , 4],
                    true = b1_e3,
                    drop = 4)
out1_b5_q3 <- stats_bi(bhat = bi1w.sim.e3[, , 5],
                    se   = si1w.sim.e3[, , 5],
                    true = b1_e3,
                    drop = 4)

out1b_b1_q3 <- stats_bi(bhat = bi1bw.sim.e3[, , 1],
                    se   = si1bw.sim.e3[, , 1],
                    true = b1_e3,
                    drop = 4)
out1b_b2_q3 <- stats_bi(bhat = bi1w.sim.e3[, , 2],
                    se   = si1w.sim.e3[, , 2],
                    true = b1_e3,
                    drop = 4)
out1b_b3_q3 <- stats_bi(bhat = bi1w.sim.e3[, , 3],
                    se   = si1w.sim.e3[, , 3],
                    true = b1_e3,
                    drop = 4)
out1b_b4_q3 <- stats_bi(bhat = bi1bw.sim.e3[, , 4],
                    se   = si1bw.sim.e3[, , 4],
                    true = b1_e3,
                    drop = 4)
out1b_b5_q3 <- stats_bi(bhat = bi1bw.sim.e3[, , 5],
                    se   = si1bw.sim.e3[, , 5],
                    true = b1_e3,
                    drop = 4)

par(mfrow = c(1, 2), cex = 0.6)
#par(cex = 1)       
plot(density(b1_e3), lwd = 2, lty = 1, 
    ylim = c(0, 2),
    xlab = expression(hat(E)(beta[i])),
    main = "A: Point Estimate",
    col = "gray0")
lines(density(out1_b1_q3$av.bi), col = "gray12", lwd = 2, lty = 2)
lines(density(out1_b2_q3$av.bi), col = "gray25", lwd = 2, lty = 3)
lines(density(out1_b3_q3$av.bi), col = "gray35", lwd = 2, lty = 4)
lines(density(out1_b4_q3$av.bi), col = "gray45", lwd = 2, lty = 5)
lines(density(out1_b5_q3$av.bi), col = "gray55", lwd = 2, lty = 6)
legend("topright", 
       c("True", "T = 1", "T = 5", "T = 10", "T = 20", "T = 50"),
       lty = c(1, 2, 3, 4, 5, 6),
       col = c("gray0", "gray12", "gray25", "gray35", "gray45", "gray55"))
plot(density(b1_e3), lwd = 2, lty = 1, 
     ylim = c(0, 2),
     xlab = expression(hat(E)(beta[i])),
     main = "B: Sampling Distribution",
     col = "gray0")
lines(density(out1b_b1_q3$av.bi), col = "gray12", lwd = 2, lty = 2)
lines(density(out1b_b2_q3$av.bi), col = "gray25", lwd = 2, lty = 3)
lines(density(out1b_b3_q3$av.bi), col = "gray35", lwd = 2, lty = 4)
lines(density(out1b_b4_q3$av.bi), col = "gray45", lwd = 2, lty = 5)
lines(density(out1b_b5_q3$av.bi), col = "gray55", lwd = 2, lty = 6)
legend("topright", 
       c("True", "T = 1", "T = 5", "T = 10", "T = 20", "T = 50"),
       lty = c(1, 2, 3, 4, 5, 6),
       col = c("gray0", "gray12", "gray25", "gray35", "gray45", "gray55"))

